"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ProcessPacketEncodePostHandlers = ProcessPacketEncodePostHandlers;
exports.ProcessPacketDecodePostHandlers = ProcessPacketDecodePostHandlers;
const SortPostHandlers_1 = require("./SortPostHandlers");
/**
 * Process packet post handlers
 * @param handlerItemsArray
 * @param asc
 */
function processPacketPostHandlers(handlerItemsArray, asc) {
    let indexFactor = 10;
    return handlerItemsArray
        .map((handlerItems) => {
        return (0, SortPostHandlers_1.SortPostHandlers)(handlerItems).map((handlerItem, index) => {
            handlerItem.priority = index + 1;
            let factor = 10;
            let priority = handlerItem.priority;
            while (priority > 1) {
                priority /= 10;
                factor *= 10;
            }
            indexFactor = indexFactor < factor ? factor : indexFactor;
            return handlerItem;
        });
    })
        .map((handlerItems, headerIndex) => {
        const basePriority = (headerIndex + 1) * indexFactor;
        const unsortedItems = handlerItems.map((handlerItem) => {
            handlerItem.priority = basePriority + handlerItem.priority;
            return handlerItem;
        });
        return asc ?
            unsortedItems.sort((a, b) => a.priority - b.priority) :
            unsortedItems.sort((a, b) => b.priority - a.priority);
    });
}
/**
 * Process packet post encode handlers
 * @param handlerItemsArray
 * @constructor
 */
function ProcessPacketEncodePostHandlers(handlerItemsArray) {
    return processPacketPostHandlers(handlerItemsArray, true).reverse().flat();
}
/**
 * Process packet post decode handlers
 * @param handlerItemsArray
 * @constructor
 */
function ProcessPacketDecodePostHandlers(handlerItemsArray) {
    return processPacketPostHandlers(handlerItemsArray, true).flat();
}
